@@ -414,7 +414,7 @@ class ifgramDict:
 ########################################################################################
 class geometryDict:
     """
-    Geometry object for Lat, Lon, Heigt, Incidence, Heading, Bperp, ... from the same platform and track.
+    Geometry object for Lat, Lon, Height, Incidence, Heading, Bperp, ... from the same platform and track.
 
     Example:
         from mintpy.utils import readfile
@@ -476,7 +476,7 @@ class geometryDict:
         if 'Y_FIRST' in self.extraMetadata.keys():
             # for dataset in geo-coordinates, use:
             # 1) incidenceAngle matrix if available OR
-            # 2) contant value from SLANT_RANGE_DISTANCE.
+            # 2) constant value from SLANT_RANGE_DISTANCE.
             ds_name = 'incidenceAngle'
             key = 'SLANT_RANGE_DISTANCE'
             if ds_name in self.dsNames:
@@ -491,7 +491,7 @@ class geometryDict:
                 data = ut.incidence_angle2slant_range_distance(self.extraMetadata, inc_angle)
 
             elif key in self.extraMetadata.keys():
-                print(f'geocoded input, use contant value from metadata {key}')
+                print(f'geocoded input, use constant value from metadata {key}')
                 length = int(self.extraMetadata['LENGTH'])
                 width = int(self.extraMetadata['WIDTH'])
                 range_dist = float(self.extraMetadata[key])
@@ -529,9 +529,9 @@ class geometryDict:
             return None
 
         if 'Y_FIRST' in self.extraMetadata.keys():
-            # for dataset in geo-coordinates, use contant value from INCIDENCE_ANGLE.
+            # for dataset in geo-coordinates, use constant value from INCIDENCE_ANGLE.
             key = 'INCIDENCE_ANGLE'
-            print(f'geocoded input, use contant value from metadata {key}')
+            print(f'geocoded input, use constant value from metadata {key}')
             if key in self.extraMetadata.keys():
                 length = int(self.extraMetadata['LENGTH'])
                 width = int(self.extraMetadata['WIDTH'])
@@ -913,7 +913,7 @@ class platformTrack:
 
         ##################
         # Despite the observation and quality files, the geometry may not exist
-        # for all pairs. Therfore we need to look at all pairs and get possible
+        # for all pairs. Therefore we need to look at all pairs and get possible
         # dataset names.
         self.dsetGeometryNames = []
         for pair in pairs:
